DiagnosticFactTag

Enum DiagnosticFactTag 

pub enum DiagnosticFactTag {
Show 89 variants AcceptedSchemaFingerprintMethod, AcceptedSchemaFingerprintHigh, AcceptedSchemaFingerprintLow, ExpectedFingerprintPrefix, ActualFingerprintPrefix, EntityTag, ExpectedEntityTag, ActualEntityTag, ConstraintId, FieldId, IndexId, RelationId, MutationOperation, RowOperation, BatchPosition, FirstBatchPosition, DuplicateBatchPosition, ClauseIndex, TermIndex, FirstTermIndex, DuplicateTermIndex, ProjectionIndex, GroupIndex, AggregateIndex, ArgumentIndex, BranchIndex, ComponentIndex, ParameterIndex, SourceSpanStart, SourceSpanEnd, Expected, Actual, Minimum, Maximum, Limit, ExpectedCount, ActualCount, ExpectedRevision, ActualRevision, CurrentRevision, RequestedRevision, ExpectedVersion, ActualVersion, CurrentVersion, RequestedVersion, ExpectedOffset, ActualOffset, ExpectedArity, ActualArity, ExpectedLength, ActualLength, ExpectedSlotCount, ActualSlotCount, RowLayout, HistoryFloor, CurrentLayout, PhysicalSlot, PhysicalGeneration, ExpectedMemoryId, ActualMemoryId, ConstraintKind, ConstraintContext, FieldKind, ValueKind, TypeFamily, FunctionKind, OperatorKind, AggregateKind, KeyNamespaceKind, ComponentKind, MismatchKind, DecodeReason, BudgetResource, MigrationPhase, DatabaseControlRecordKind, StateKind, PayloadComponent, ExpectedSignaturePrefix, ActualSignaturePrefix, FindingPosition, RootField, RecordMember, TupleElement, Newtype, EnumVariant, ListElement, SetElement, MapEntryKey, MapEntryValue,
}
Stable semantic identity for one numeric public diagnostic fact.

Variants



AcceptedSchemaFingerprintMethod

Public fact tag 1.



AcceptedSchemaFingerprintHigh

Public fact tag 2.



AcceptedSchemaFingerprintLow

Public fact tag 3.



ExpectedFingerprintPrefix

Public fact tag 4.



ActualFingerprintPrefix

Public fact tag 5.



EntityTag

Public fact tag 6.



ExpectedEntityTag

Public fact tag 7.



ActualEntityTag

Public fact tag 8.



ConstraintId

Public fact tag 9.



FieldId

Public fact tag 10.



IndexId

Public fact tag 11.



RelationId

Public fact tag 12.



MutationOperation

Public fact tag 13.



RowOperation

Public fact tag 14.



BatchPosition

Public fact tag 15.



FirstBatchPosition

Public fact tag 16.



DuplicateBatchPosition

Public fact tag 17.



ClauseIndex

Public fact tag 18.



TermIndex

Public fact tag 19.



FirstTermIndex

Public fact tag 20.



DuplicateTermIndex

Public fact tag 21.



ProjectionIndex

Public fact tag 22.



GroupIndex

Public fact tag 23.



AggregateIndex

Public fact tag 24.



ArgumentIndex

Public fact tag 25.



BranchIndex

Public fact tag 26.



ComponentIndex

Public fact tag 27.



ParameterIndex

Public fact tag 28.



SourceSpanStart

Public fact tag 29.



SourceSpanEnd

Public fact tag 30.



Expected

Public fact tag 31.



Actual

Public fact tag 32.



Minimum

Public fact tag 33.



Maximum

Public fact tag 34.



Limit

Public fact tag 35.



ExpectedCount

Public fact tag 36.



ActualCount

Public fact tag 37.



ExpectedRevision

Public fact tag 38.



ActualRevision

Public fact tag 39.



CurrentRevision

Public fact tag 40.



RequestedRevision

Public fact tag 41.



ExpectedVersion

Public fact tag 42.



ActualVersion

Public fact tag 43.



CurrentVersion

Public fact tag 44.



RequestedVersion

Public fact tag 45.



ExpectedOffset

Public fact tag 46.



ActualOffset

Public fact tag 47.



ExpectedArity

Public fact tag 48.



ActualArity

Public fact tag 49.



ExpectedLength

Public fact tag 50.



ActualLength

Public fact tag 51.



ExpectedSlotCount

Public fact tag 52.



ActualSlotCount

Public fact tag 53.



RowLayout

Public fact tag 54.



HistoryFloor

Public fact tag 55.



CurrentLayout

Public fact tag 56.



PhysicalSlot

Public fact tag 57.



PhysicalGeneration

Public fact tag 58.



ExpectedMemoryId

Public fact tag 59.



ActualMemoryId

Public fact tag 60.



ConstraintKind

Public fact tag 61.



ConstraintContext

Public fact tag 62.



FieldKind

Public fact tag 63.



ValueKind

Public fact tag 64.



TypeFamily

Public fact tag 65.



FunctionKind

Public fact tag 66.



OperatorKind

Public fact tag 67.



AggregateKind

Public fact tag 68.



KeyNamespaceKind

Public fact tag 69.



ComponentKind

Public fact tag 70.



MismatchKind

Public fact tag 71.



DecodeReason

Public fact tag 72.



BudgetResource

Public fact tag 73.



MigrationPhase

Public fact tag 74.



DatabaseControlRecordKind

Public fact tag 75.



StateKind

Public fact tag 76.



PayloadComponent

Public fact tag 77.



ExpectedSignaturePrefix

Public fact tag 78.



ActualSignaturePrefix

Public fact tag 79.



FindingPosition

Public fact tag 80.



RootField

Public fact tag 81.



RecordMember

Public fact tag 82.



TupleElement

Public fact tag 83.



Newtype

Public fact tag 84.



EnumVariant

Public fact tag 85.



ListElement

Public fact tag 86.



SetElement

Public fact tag 87.



MapEntryKey

Public fact tag 88.



MapEntryValue

Public fact tag 89.

Implementations

Source

impl DiagnosticFactTag

pub const fn raw(self) -> u8

Return the fixed public wire value.

pub const fn known(raw: u8) -> Option<Self>

Recover a known tag from its public wire value.