DiagnosticFunctionKind

Enum DiagnosticFunctionKind 

pub enum DiagnosticFunctionKind {
Show 39 variants Abs, Cbrt, Ceiling, Coalesce, CollectionContains, Contains, EndsWith, Exp, Floor, IsEmpty, IsMissing, IsNotEmpty, IsNotNull, IsNull, Left, Length, Ln, Log, Log2, Log10, Lower, Ltrim, Mod, NullIf, OctetLength, Position, Power, Replace, Right, Round, Rtrim, Sign, Sqrt, StartsWith, Substring, Trim, Trunc, Upper, InList,
}
Compact function identity carried by DiagnosticFactTag::FunctionKind.

Variants



Abs

Compact diagnostic value 1.



Cbrt

Compact diagnostic value 2.



Ceiling

Compact diagnostic value 3.



Coalesce

Compact diagnostic value 4.



CollectionContains

Compact diagnostic value 5.



Contains

Compact diagnostic value 6.



EndsWith

Compact diagnostic value 7.



Exp

Compact diagnostic value 8.



Floor

Compact diagnostic value 9.



IsEmpty

Compact diagnostic value 10.



IsMissing

Compact diagnostic value 11.



IsNotEmpty

Compact diagnostic value 12.



IsNotNull

Compact diagnostic value 13.



IsNull

Compact diagnostic value 14.



Left

Compact diagnostic value 15.



Length

Compact diagnostic value 16.



Ln

Compact diagnostic value 17.



Log

Compact diagnostic value 18.



Log2

Compact diagnostic value 19.



Log10

Compact diagnostic value 20.



Lower

Compact diagnostic value 21.



Ltrim

Compact diagnostic value 22.



Mod

Compact diagnostic value 23.



NullIf

Compact diagnostic value 24.



OctetLength

Compact diagnostic value 25.



Position

Compact diagnostic value 26.



Power

Compact diagnostic value 27.



Replace

Compact diagnostic value 28.



Right

Compact diagnostic value 29.



Round

Compact diagnostic value 30.



Rtrim

Compact diagnostic value 31.



Sign

Compact diagnostic value 32.



Sqrt

Compact diagnostic value 33.



StartsWith

Compact diagnostic value 34.



Substring

Compact diagnostic value 35.



Trim

Compact diagnostic value 36.



Trunc

Compact diagnostic value 37.



Upper

Compact diagnostic value 38.



InList

Compact diagnostic value 39.

Implementations

Source

impl DiagnosticFunctionKind

pub const fn raw(self) -> u64

Return the fixed numeric fact value.

pub const fn known(raw: u64) -> Option<Self>

Recover a known compact value from its public numeric identity.