pub struct Diagnostic { /* private fields */ }Expand description
Diagnostic
Compact public diagnostic payload.
Implementations
Sourceimpl Diagnostic
impl Diagnostic
Sourcepub const fn new(
code: DiagnosticCode,
origin: ErrorOrigin,
detail: Option<DiagnosticDetail>,
) -> Self
pub const fn new( code: DiagnosticCode, origin: ErrorOrigin, detail: Option<DiagnosticDetail>, ) -> Self
Build a compact diagnostic from a code and optional structured detail.
Sourcepub const fn from_code(code: DiagnosticCode) -> Self
pub const fn from_code(code: DiagnosticCode) -> Self
Build a compact diagnostic using the code’s default origin.
Sourcepub const fn code(&self) -> DiagnosticCode
pub const fn code(&self) -> DiagnosticCode
Return the stable diagnostic code.
Sourcepub const fn class(&self) -> ErrorClass
pub const fn class(&self) -> ErrorClass
Return the diagnostic class.
Sourcepub const fn origin(&self) -> ErrorOrigin
pub const fn origin(&self) -> ErrorOrigin
Return the subsystem origin.
Sourcepub const fn detail(&self) -> Option<&DiagnosticDetail>
pub const fn detail(&self) -> Option<&DiagnosticDetail>
Return structured diagnostic detail, when available.
Sourcepub const fn error_code(&self) -> ErrorCode
pub const fn error_code(&self) -> ErrorCode
Return the numeric public wire code for this diagnostic.